Package: mpactr
Title: Correction of Preprocessed MS Data
Version: 0.3.3
Authors@R: c(
    person("Allison", "Mason", , "masonar@umich.edu", role = c("aut"),
            comment = c(ORCID = "0000-0003-1339-1592")),
    person("Gregory", "Johnson", , "grejoh@umich.edu", role = c("aut"),
            comment = c(ORCID = "0009-0008-3890-0297")),
    person("Patrick", "Schloss", , "pschloss@umich.edu", role = c("aut", "cre", "cph"),
            comment = c(ORCID = "0000-0002-6935-4275"))
    )
Description: An 'R' implementation of the 'python' program Metabolomics Peak Analysis Computational Tool ('MPACT') (Robert M. Samples, Sara P. Puckett, and Marcy J. Balunas (2023) <doi:10.1021/acs.analchem.2c04632>). Filters in the package serve to address common errors in tandem mass spectrometry preprocessing, including: (1) isotopic patterns that are incorrectly split during preprocessing, (2) features present in solvent blanks due to carryover between samples, (3) features whose abundance is greater than user-defined abundance threshold in a specific group of samples, for example media blanks, (4) ions that are inconsistent between technical replicates, and (5) in-source fragment ions created during ionization before fragmentation in the tandem mass spectrometry workflow.
Encoding: UTF-8
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), tidyverse, plotly,
        Hmisc, corrplot, ggdendro, ggtext
Config/testthat/edition: 3
Imports: cli, data.table, ggplot2, R6, Rcpp, stats, treemapify, viridis
LazyData: true
URL: https://www.mums2.org/mpactr/, https://github.com/mums2/mpactr
BugReports: https://github.com/mums2/mpactr/issues
VignetteBuilder: knitr
LinkingTo: Rcpp
License: GPL (>= 3)
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-20 15:45:21 UTC; grejoh
Author: Allison Mason [aut] (ORCID: <https://orcid.org/0000-0003-1339-1592>),
  Gregory Johnson [aut] (ORCID: <https://orcid.org/0009-0008-3890-0297>),
  Patrick Schloss [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-6935-4275>)
Maintainer: Patrick Schloss <pschloss@umich.edu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-05-21 17:20:10 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-25 03:37:48 UTC; unix
Archs: mpactr.so.dSYM
