#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom cli cli_abort
#' @importFrom cli cli_alert_info
#' @importFrom cli cli_alert_success
#' @importFrom data.table address
#' @importFrom data.table as.data.table
#' @importFrom data.table copy
#' @importFrom data.table data.table
#' @importFrom data.table dcast
#' @importFrom data.table fread
#' @importFrom data.table melt
#' @importFrom data.table setDTthreads
#' @importFrom data.table setnames
#' @importFrom data.table setorder
#' @importFrom ggplot2 aes
#' @importFrom ggplot2 ggplot
#' @importFrom ggplot2 is_ggplot
#' @importFrom ggplot2 theme
#' @importFrom R6 R6Class
#' @importFrom Rcpp sourceCpp
#' @importFrom stats cor
#' @importFrom stats cutree
#' @importFrom stats dist
#' @importFrom stats hclust
#' @importFrom stats sd
#' @importFrom treemapify geom_treemap
#' @importFrom treemapify geom_treemap_text
#' @importFrom viridis scale_fill_viridis
#' @useDynLib mpactr, .registration = TRUE
## usethis namespace: end
NULL
