# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

FilterMispickedIons <- function(peakTable, ringWin, isoWin, trWin, maxIsoShift) {
    .Call(`_mpactr_FilterMispickedIons`, peakTable, ringWin, isoWin, trWin, maxIsoShift)
}

FilterCV <- function(peakTable, uniqueSampleList, cvCutOff, replicates) {
    .Call(`_mpactr_FilterCV`, peakTable, uniqueSampleList, cvCutOff, replicates)
}

UniqueDuplicates <- function(compoundNames) {
    .Call(`_mpactr_UniqueDuplicates`, compoundNames)
}

