% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mpactr-accessors.R
\name{get_metadata}
\alias{get_metadata}
\title{Return the meta_data data.table from the mpactr object.}
\usage{
get_metadata(mpactr_object)
}
\arguments{
\item{mpactr_object}{The mpactr object that is created by calling
the import_data() function.}
}
\value{
a \code{data.table}.
}
\description{
\code{get_metadata()} a wrapper function to return the meta data object
of the given mpactr object.
}
\examples{
 \dontshow{
limit_cores()
}
data <- import_data(
  example_path("coculture_peak_table.csv"),
  example_path("metadata.csv"),
  format = "Progenesis"
)

meta_data <- get_metadata(data)

}
